diff --git a/osu.Game/Rulesets/UI/Scrolling/ScrollingHitObjectContainer.cs b/osu.Game/Rulesets/UI/Scrolling/ScrollingHitObjectContainer.cs
index 283d84e8df..061c9aa948 100644
--- a/osu.Game/Rulesets/UI/Scrolling/ScrollingHitObjectContainer.cs
+++ b/osu.Game/Rulesets/UI/Scrolling/ScrollingHitObjectContainer.cs
@@ -53,19 +53,23 @@ namespace osu.Game.Rulesets.UI.Scrolling
}
///
- /// Given a position along the scrolling axis, return the time within this .
+ /// Given a position at , return the time of the object corresponding the position.
///
- /// The position along the scrolling axis.
- /// The time the scrolling speed is used.
- public double TimeAtPosition(float position, double referenceTime)
+ ///
+ /// If there are multiple valid time values, one arbitrary time is returned.
+ ///
+ public double TimeAtPosition(float position, double currentTime)
{
flipPositionIfRequired(ref position);
- return scrollingInfo.Algorithm.TimeAt(position, referenceTime, timeRange.Value, scrollLength);
+ return scrollingInfo.Algorithm.TimeAt(position, currentTime, timeRange.Value, scrollLength);
}
///
/// Given a position in screen space, return the time within this .
///
+ ///
+ /// If there are multiple valid time values, one arbitrary time is returned.
+ ///
public double TimeAtScreenSpacePosition(Vector2 screenSpacePosition)
{
Vector2 position = ToLocalSpace(screenSpacePosition);
@@ -53,19 +53,23 @@ namespace osu.Game.Rulesets.UI.Scrolling
}
///
- /// Given a position in screen space, return the time within this .
+ /// Given a position at the current time in screen space, return the time of the object corresponding the position.
///